@@ -905,7 +905,12 @@ predict.rirt <- function(object, select=NULL, type=NULL,
         nbr=as.integer(0), mean=as.double(0), 
         sd=as.double(0), alpha=as.double(0),
         pairs.corr=as.double(rep(0,nbr.item*nbr.item)),
+        freq.table=as.integer(rep(0,nbr.item*3)),
         PACKAGE="rirt", NAOK=TRUE, DUP=FALSE)
+      out$freq.table <- lapply(1:nbr.item, function(j){
+          item.freq <- out$freq.table[(j-1)*3+(1:3)]
+          names(item.freq) <- c("NA", "0", "1")
+          item.freq})
       ctt <- list(
         items=data.frame(item=item,
           mean=out$items.mean, sd=out$items.sd,
@@ -914,7 +919,8 @@ predict.rirt <- function(object, select=NULL, type=NULL,
         subjects=data.frame(subject=subject,
           score=out$subjects.score, nbr=out$subjects.nbr),
         nbr=out$nbr, mean=out$mean, sd=out$sd, alpha=out$alpha, 
-        pairs.corr=matrix(out$pairs.corr, nrow=nbr.item))
+        pairs.corr=matrix(out$pairs.corr, nrow=nbr.item),
+        freq.table=out$freq.table)
       class(ctt) <- c("rirtctt", class(ctt))
       return(ctt)
 
@@ -1120,7 +1126,12 @@ predict.rirt <- function(object, select=NULL, type=NULL,
                 nbr=as.integer(0), mean=as.double(0), 
                 sd=as.double(0), alpha=as.double(0),
                 pairs.corr=as.double(rep(0,nbr.item*nbr.item)),
+                freq.table=as.integer(rep(0,nbr.item+nbr.option.tot)),
                 PACKAGE="rirt", NAOK=TRUE, DUP=FALSE)
+      out$freq.table <- lapply(1:nbr.item, function(j){
+          item.freq <- out$freq.table[items.pos[j]+j+(0:(nbr.options[j]))]
+          names(item.freq) <- c("NA", options.label[[j]])
+          item.freq})
       ctt <- list(
         items=data.frame(item=item.unique,
           mean=out$items.mean, sd=out$items.sd,
@@ -1129,7 +1140,8 @@ predict.rirt <- function(object, select=NULL, type=NULL,
         subjects=data.frame(subject=subject,
           score=out$subjects.score, nbr=out$subjects.nbr),
         nbr=out$nbr, mean=out$mean, sd=out$sd, alpha=out$alpha,
-        pairs.corr=matrix(out$pairs.corr, nrow=nbr.item))
+        pairs.corr=matrix(out$pairs.corr, nrow=nbr.item),
+        freq.table=out$freq.table)
       class(ctt) <- c("rirtctt", class(ctt))
       return(ctt)
 
